Class: ClickSendClient::ContactApi
- Inherits:
-
Object
- Object
- ClickSendClient::ContactApi
- Defined in:
- lib/clicksend_client/api/contact_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ContactApi
constructor
A new instance of ContactApi.
-
#lists_contacts_by_list_id_and_contact_id_delete(list_id, contact_id, opts = {}) ⇒ String
Delete a contact Delete a contact.
-
#lists_contacts_by_list_id_and_contact_id_delete_with_http_info(list_id, contact_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Delete a contact Delete a contact.
-
#lists_contacts_by_list_id_and_contact_id_get(list_id, contact_id, opts = {}) ⇒ String
Get a specific contact Get a specific contact.
-
#lists_contacts_by_list_id_and_contact_id_get_with_http_info(list_id, contact_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Get a specific contact Get a specific contact.
-
#lists_contacts_by_list_id_and_contact_id_put(list_id, contact_id, contact, opts = {}) ⇒ String
Update specific contact Update specific contact.
-
#lists_contacts_by_list_id_and_contact_id_put_with_http_info(list_id, contact_id, contact, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Update specific contact Update specific contact.
-
#lists_contacts_by_list_id_get(list_id, opts = {}) ⇒ String
Get all contacts in a list Get all contacts in a list.
-
#lists_contacts_by_list_id_get_with_http_info(list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Get all contacts in a list Get all contacts in a list.
-
#lists_contacts_by_list_id_post(contact, list_id, opts = {}) ⇒ String
Create new contact Create new contact.
-
#lists_contacts_by_list_id_post_with_http_info(contact, list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Create new contact Create new contact.
-
#lists_copy_contact_put(from_list_id, contact_id, to_list_id, opts = {}) ⇒ String
Copy contact to another list Copy contact to another list.
-
#lists_copy_contact_put_with_http_info(from_list_id, contact_id, to_list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Copy contact to another list Copy contact to another list.
-
#lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put(list_id, opt_out_list_id, opts = {}) ⇒ String
Remove all opted out contacts Remove all opted out contacts.
-
#lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put_with_http_info(list_id, opt_out_list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Remove all opted out contacts Remove all opted out contacts.
-
#lists_transfer_contact_put(from_list_id, contact_id, to_list_id, opts = {}) ⇒ String
Transfer contact to another list Transfer contact to another list.
-
#lists_transfer_contact_put_with_http_info(from_list_id, contact_id, to_list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Transfer contact to another list Transfer contact to another list.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContactApi
Returns a new instance of ContactApi.
19 20 21 |
# File 'lib/clicksend_client/api/contact_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/clicksend_client/api/contact_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#lists_contacts_by_list_id_and_contact_id_delete(list_id, contact_id, opts = {}) ⇒ String
Delete a contact Delete a contact
28 29 30 31 |
# File 'lib/clicksend_client/api/contact_api.rb', line 28 def lists_contacts_by_list_id_and_contact_id_delete(list_id, contact_id, opts = {}) data, _status_code, _headers = lists_contacts_by_list_id_and_contact_id_delete_with_http_info(list_id, contact_id, opts) data end |
#lists_contacts_by_list_id_and_contact_id_delete_with_http_info(list_id, contact_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Delete a contact Delete a contact
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/clicksend_client/api/contact_api.rb', line 39 def lists_contacts_by_list_id_and_contact_id_delete_with_http_info(list_id, contact_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContactApi.lists_contacts_by_list_id_and_contact_id_delete ...' end # verify the required parameter 'list_id' is set if @api_client.config.client_side_validation && list_id.nil? fail ArgumentError, "Missing the required parameter 'list_id' when calling ContactApi.lists_contacts_by_list_id_and_contact_id_delete" end # verify the required parameter 'contact_id' is set if @api_client.config.client_side_validation && contact_id.nil? fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactApi.lists_contacts_by_list_id_and_contact_id_delete" end # resource path local_var_path = '/lists/{list_id}/contacts/{contact_id}'.sub('{' + 'list_id' + '}', list_id.to_s).sub('{' + 'contact_id' + '}', contact_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['BasicAuth'] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ContactApi#lists_contacts_by_list_id_and_contact_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lists_contacts_by_list_id_and_contact_id_get(list_id, contact_id, opts = {}) ⇒ String
Get a specific contact Get a specific contact
88 89 90 91 |
# File 'lib/clicksend_client/api/contact_api.rb', line 88 def lists_contacts_by_list_id_and_contact_id_get(list_id, contact_id, opts = {}) data, _status_code, _headers = lists_contacts_by_list_id_and_contact_id_get_with_http_info(list_id, contact_id, opts) data end |
#lists_contacts_by_list_id_and_contact_id_get_with_http_info(list_id, contact_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Get a specific contact Get a specific contact
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/clicksend_client/api/contact_api.rb', line 99 def lists_contacts_by_list_id_and_contact_id_get_with_http_info(list_id, contact_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContactApi.lists_contacts_by_list_id_and_contact_id_get ...' end # verify the required parameter 'list_id' is set if @api_client.config.client_side_validation && list_id.nil? fail ArgumentError, "Missing the required parameter 'list_id' when calling ContactApi.lists_contacts_by_list_id_and_contact_id_get" end # verify the required parameter 'contact_id' is set if @api_client.config.client_side_validation && contact_id.nil? fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactApi.lists_contacts_by_list_id_and_contact_id_get" end # resource path local_var_path = '/lists/{list_id}/contacts/{contact_id}'.sub('{' + 'list_id' + '}', list_id.to_s).sub('{' + 'contact_id' + '}', contact_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['BasicAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ContactApi#lists_contacts_by_list_id_and_contact_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lists_contacts_by_list_id_and_contact_id_put(list_id, contact_id, contact, opts = {}) ⇒ String
Update specific contact Update specific contact
149 150 151 152 |
# File 'lib/clicksend_client/api/contact_api.rb', line 149 def lists_contacts_by_list_id_and_contact_id_put(list_id, contact_id, contact, opts = {}) data, _status_code, _headers = lists_contacts_by_list_id_and_contact_id_put_with_http_info(list_id, contact_id, contact, opts) data end |
#lists_contacts_by_list_id_and_contact_id_put_with_http_info(list_id, contact_id, contact, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Update specific contact Update specific contact
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/clicksend_client/api/contact_api.rb', line 161 def lists_contacts_by_list_id_and_contact_id_put_with_http_info(list_id, contact_id, contact, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContactApi.lists_contacts_by_list_id_and_contact_id_put ...' end # verify the required parameter 'list_id' is set if @api_client.config.client_side_validation && list_id.nil? fail ArgumentError, "Missing the required parameter 'list_id' when calling ContactApi.lists_contacts_by_list_id_and_contact_id_put" end # verify the required parameter 'contact_id' is set if @api_client.config.client_side_validation && contact_id.nil? fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactApi.lists_contacts_by_list_id_and_contact_id_put" end # verify the required parameter 'contact' is set if @api_client.config.client_side_validation && contact.nil? fail ArgumentError, "Missing the required parameter 'contact' when calling ContactApi.lists_contacts_by_list_id_and_contact_id_put" end # resource path local_var_path = '/lists/{list_id}/contacts/{contact_id}'.sub('{' + 'list_id' + '}', list_id.to_s).sub('{' + 'contact_id' + '}', contact_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(contact) auth_names = ['BasicAuth'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ContactApi#lists_contacts_by_list_id_and_contact_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lists_contacts_by_list_id_get(list_id, opts = {}) ⇒ String
Get all contacts in a list Get all contacts in a list
216 217 218 219 |
# File 'lib/clicksend_client/api/contact_api.rb', line 216 def lists_contacts_by_list_id_get(list_id, opts = {}) data, _status_code, _headers = lists_contacts_by_list_id_get_with_http_info(list_id, opts) data end |
#lists_contacts_by_list_id_get_with_http_info(list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Get all contacts in a list Get all contacts in a list
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/clicksend_client/api/contact_api.rb', line 229 def lists_contacts_by_list_id_get_with_http_info(list_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContactApi.lists_contacts_by_list_id_get ...' end # verify the required parameter 'list_id' is set if @api_client.config.client_side_validation && list_id.nil? fail ArgumentError, "Missing the required parameter 'list_id' when calling ContactApi.lists_contacts_by_list_id_get" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ContactApi.lists_contacts_by_list_id_get, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ContactApi.lists_contacts_by_list_id_get, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'updated_after'].nil? && opts[:'updated_after'] < 1 fail ArgumentError, 'invalid value for "opts[:"updated_after"]" when calling ContactApi.lists_contacts_by_list_id_get, must be greater than or equal to 1.' end # resource path local_var_path = '/lists/{list_id}/contacts'.sub('{' + 'list_id' + '}', list_id.to_s) # query parameters query_params = {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'updated_after'] = opts[:'updated_after'] if !opts[:'updated_after'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['BasicAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ContactApi#lists_contacts_by_list_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lists_contacts_by_list_id_post(contact, list_id, opts = {}) ⇒ String
Create new contact Create new contact
289 290 291 292 |
# File 'lib/clicksend_client/api/contact_api.rb', line 289 def lists_contacts_by_list_id_post(contact, list_id, opts = {}) data, _status_code, _headers = lists_contacts_by_list_id_post_with_http_info(contact, list_id, opts) data end |
#lists_contacts_by_list_id_post_with_http_info(contact, list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Create new contact Create new contact
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/clicksend_client/api/contact_api.rb', line 300 def lists_contacts_by_list_id_post_with_http_info(contact, list_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContactApi.lists_contacts_by_list_id_post ...' end # verify the required parameter 'contact' is set if @api_client.config.client_side_validation && contact.nil? fail ArgumentError, "Missing the required parameter 'contact' when calling ContactApi.lists_contacts_by_list_id_post" end # verify the required parameter 'list_id' is set if @api_client.config.client_side_validation && list_id.nil? fail ArgumentError, "Missing the required parameter 'list_id' when calling ContactApi.lists_contacts_by_list_id_post" end # resource path local_var_path = '/lists/{list_id}/contacts'.sub('{' + 'list_id' + '}', list_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(contact) auth_names = ['BasicAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ContactApi#lists_contacts_by_list_id_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lists_copy_contact_put(from_list_id, contact_id, to_list_id, opts = {}) ⇒ String
Copy contact to another list Copy contact to another list
350 351 352 353 |
# File 'lib/clicksend_client/api/contact_api.rb', line 350 def lists_copy_contact_put(from_list_id, contact_id, to_list_id, opts = {}) data, _status_code, _headers = lists_copy_contact_put_with_http_info(from_list_id, contact_id, to_list_id, opts) data end |
#lists_copy_contact_put_with_http_info(from_list_id, contact_id, to_list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Copy contact to another list Copy contact to another list
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/clicksend_client/api/contact_api.rb', line 362 def lists_copy_contact_put_with_http_info(from_list_id, contact_id, to_list_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContactApi.lists_copy_contact_put ...' end # verify the required parameter 'from_list_id' is set if @api_client.config.client_side_validation && from_list_id.nil? fail ArgumentError, "Missing the required parameter 'from_list_id' when calling ContactApi.lists_copy_contact_put" end # verify the required parameter 'contact_id' is set if @api_client.config.client_side_validation && contact_id.nil? fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactApi.lists_copy_contact_put" end # verify the required parameter 'to_list_id' is set if @api_client.config.client_side_validation && to_list_id.nil? fail ArgumentError, "Missing the required parameter 'to_list_id' when calling ContactApi.lists_copy_contact_put" end # resource path local_var_path = '/lists/{from_list_id}/contacts/{contact_id}/copy/{to_list_id}'.sub('{' + 'from_list_id' + '}', from_list_id.to_s).sub('{' + 'contact_id' + '}', contact_id.to_s).sub('{' + 'to_list_id' + '}', to_list_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['BasicAuth'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ContactApi#lists_copy_contact_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put(list_id, opt_out_list_id, opts = {}) ⇒ String
Remove all opted out contacts Remove all opted out contacts
415 416 417 418 |
# File 'lib/clicksend_client/api/contact_api.rb', line 415 def lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put(list_id, opt_out_list_id, opts = {}) data, _status_code, _headers = lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put_with_http_info(list_id, opt_out_list_id, opts) data end |
#lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put_with_http_info(list_id, opt_out_list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Remove all opted out contacts Remove all opted out contacts
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/clicksend_client/api/contact_api.rb', line 426 def lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put_with_http_info(list_id, opt_out_list_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContactApi.lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put ...' end # verify the required parameter 'list_id' is set if @api_client.config.client_side_validation && list_id.nil? fail ArgumentError, "Missing the required parameter 'list_id' when calling ContactApi.lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put" end # verify the required parameter 'opt_out_list_id' is set if @api_client.config.client_side_validation && opt_out_list_id.nil? fail ArgumentError, "Missing the required parameter 'opt_out_list_id' when calling ContactApi.lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put" end # resource path local_var_path = '/lists/{list_id}/remove-opted-out-contacts/{opt_out_list_id}'.sub('{' + 'list_id' + '}', list_id.to_s).sub('{' + 'opt_out_list_id' + '}', opt_out_list_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['BasicAuth'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ContactApi#lists_remove_opted_out_contacts_by_list_id_and_opt_out_list_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lists_transfer_contact_put(from_list_id, contact_id, to_list_id, opts = {}) ⇒ String
Transfer contact to another list Transfer contact to another list
476 477 478 479 |
# File 'lib/clicksend_client/api/contact_api.rb', line 476 def lists_transfer_contact_put(from_list_id, contact_id, to_list_id, opts = {}) data, _status_code, _headers = lists_transfer_contact_put_with_http_info(from_list_id, contact_id, to_list_id, opts) data end |
#lists_transfer_contact_put_with_http_info(from_list_id, contact_id, to_list_id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Transfer contact to another list Transfer contact to another list
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/clicksend_client/api/contact_api.rb', line 488 def lists_transfer_contact_put_with_http_info(from_list_id, contact_id, to_list_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContactApi.lists_transfer_contact_put ...' end # verify the required parameter 'from_list_id' is set if @api_client.config.client_side_validation && from_list_id.nil? fail ArgumentError, "Missing the required parameter 'from_list_id' when calling ContactApi.lists_transfer_contact_put" end # verify the required parameter 'contact_id' is set if @api_client.config.client_side_validation && contact_id.nil? fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactApi.lists_transfer_contact_put" end # verify the required parameter 'to_list_id' is set if @api_client.config.client_side_validation && to_list_id.nil? fail ArgumentError, "Missing the required parameter 'to_list_id' when calling ContactApi.lists_transfer_contact_put" end # resource path local_var_path = '/lists/{from_list_id}/contacts/{contact_id}/transfer/{to_list_id}'.sub('{' + 'from_list_id' + '}', from_list_id.to_s).sub('{' + 'contact_id' + '}', contact_id.to_s).sub('{' + 'to_list_id' + '}', to_list_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['BasicAuth'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ContactApi#lists_transfer_contact_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |