Class: ClickSendClient::GlobalSendingApi

Inherits:
Object
  • Object
show all
Defined in:
lib/clicksend_client/api/global_sending_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ GlobalSendingApi

Returns a new instance of GlobalSendingApi.



19
20
21
# File 'lib/clicksend_client/api/global_sending_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/clicksend_client/api/global_sending_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#list_countries_get(opts = {}) ⇒ String

List of countries List of countries with IDs that can be used in selecting countries for Global sending.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


26
27
28
29
# File 'lib/clicksend_client/api/global_sending_api.rb', line 26

def list_countries_get(opts = {})
  data, _status_code, _headers = list_countries_get_with_http_info(opts)
  data
end

#list_countries_get_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>

List of countries List of countries with IDs that can be used in selecting countries for Global sending.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/clicksend_client/api/global_sending_api.rb', line 35

def list_countries_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GlobalSendingApi.list_countries_get ...'
  end
  # resource path
  local_var_path = '/country-list'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['BasicAuth']
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GlobalSendingApi#list_countries_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#user_countries_agree_post(opts = {}) ⇒ String

Agree to rules and regulation To agree on rules and regulations of selected countries and confirm selection.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


74
75
76
77
# File 'lib/clicksend_client/api/global_sending_api.rb', line 74

def user_countries_agree_post(opts = {})
  data, _status_code, _headers = user_countries_agree_post_with_http_info(opts)
  data
end

#user_countries_agree_post_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Agree to rules and regulation To agree on rules and regulations of selected countries and confirm selection.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/clicksend_client/api/global_sending_api.rb', line 83

def user_countries_agree_post_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GlobalSendingApi.user_countries_agree_post ...'
  end
  # resource path
  local_var_path = '/user-countries/agree'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['BasicAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GlobalSendingApi#user_countries_agree_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#user_countries_get(opts = {}) ⇒ String

Get Countries for Global Sending Get the list of selected countries.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


122
123
124
125
# File 'lib/clicksend_client/api/global_sending_api.rb', line 122

def user_countries_get(opts = {})
  data, _status_code, _headers = user_countries_get_with_http_info(opts)
  data
end

#user_countries_get_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Get Countries for Global Sending Get the list of selected countries.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/clicksend_client/api/global_sending_api.rb', line 131

def user_countries_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GlobalSendingApi.user_countries_get ...'
  end
  # resource path
  local_var_path = '/user-countries'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['BasicAuth']
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GlobalSendingApi#user_countries_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#user_countries_post(country_list_ids, opts = {}) ⇒ String

Select Countries for Global Sending Use this endpoint to select countries that you intend to send sms / mms to. To remove / unselect a country, just remove the country id from the array in the payload.

Parameters:

  • country_list_ids

    Id of countr(ies) you want to select, you can get them from GET /country-list response

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


171
172
173
174
# File 'lib/clicksend_client/api/global_sending_api.rb', line 171

def user_countries_post(country_list_ids, opts = {})
  data, _status_code, _headers = user_countries_post_with_http_info(country_list_ids, opts)
  data
end

#user_countries_post_with_http_info(country_list_ids, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Select Countries for Global Sending Use this endpoint to select countries that you intend to send sms / mms to. To remove / unselect a country, just remove the country id from the array in the payload.

Parameters:

  • country_list_ids

    Id of countr(ies) you want to select, you can get them from GET /country-list response

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/clicksend_client/api/global_sending_api.rb', line 181

def user_countries_post_with_http_info(country_list_ids, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GlobalSendingApi.user_countries_post ...'
  end
  # verify the required parameter 'country_list_ids' is set
  if @api_client.config.client_side_validation && country_list_ids.nil?
    fail ArgumentError, "Missing the required parameter 'country_list_ids' when calling GlobalSendingApi.user_countries_post"
  end
  # resource path
  local_var_path = '/user-countries'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(country_list_ids)
  auth_names = ['BasicAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GlobalSendingApi#user_countries_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end